==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PageRootLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PageRootLinks
 */
@JsonPropertyOrder({ PageRootLinks.JSON_PROPERTY_SELF, PageRootLinks.JSON_PROPERTY_DEFAULT,
        PageRootLinks.JSON_PROPERTY_CUSTOMIZED, PageRootLinks.JSON_PROPERTY_PREVIEW })
@JsonTypeName("PageRoot__links")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PageRootLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEFAULT = "default";
    private HrefObject _default;

    public static final String JSON_PROPERTY_CUSTOMIZED = "customized";
    private HrefObject customized;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private HrefObject preview;

    public PageRootLinks() {
    }

    public PageRootLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public PageRootLinks _default(HrefObject _default) {

        this._default = _default;
        return this;
    }

    /**
     * Get _default
     *
     * @return _default
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDefault() {
        return _default;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefault(HrefObject _default) {
        this._default = _default;
    }

    public PageRootLinks customized(HrefObject customized) {

        this.customized = customized;
        return this;
    }

    /**
     * Get customized
     *
     * @return customized
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getCustomized() {
        return customized;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomized(HrefObject customized) {
        this.customized = customized;
    }

    public PageRootLinks preview(HrefObject preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(HrefObject preview) {
        this.preview = preview;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PageRootLinks pageRootLinks = (PageRootLinks) o;
        return Objects.equals(this.self, pageRootLinks.self) && Objects.equals(this._default, pageRootLinks._default)
                && Objects.equals(this.customized, pageRootLinks.customized)
                && Objects.equals(this.preview, pageRootLinks.preview);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, _default, customized, preview);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PageRootLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    _default: ").append(toIndentedString(_default)).append("\n");
        sb.append("    customized: ").append(toIndentedString(customized)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PageRootLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PageRootLinks
 */
@JsonPropertyOrder({ PageRootLinks.JSON_PROPERTY_SELF, PageRootLinks.JSON_PROPERTY_DEFAULT,
        PageRootLinks.JSON_PROPERTY_CUSTOMIZED, PageRootLinks.JSON_PROPERTY_PREVIEW })
@JsonTypeName("PageRoot__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PageRootLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_DEFAULT = "default";
    private HrefObject _default;

    public static final String JSON_PROPERTY_CUSTOMIZED = "customized";
    private HrefObject customized;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private HrefObject preview;

    public PageRootLinks() {
    }

    public PageRootLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public PageRootLinks _default(HrefObject _default) {

        this._default = _default;
        return this;
    }

    /**
     * Get _default
     *
     * @return _default
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDefault() {
        return _default;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefault(HrefObject _default) {
        this._default = _default;
    }

    public PageRootLinks customized(HrefObject customized) {

        this.customized = customized;
        return this;
    }

    /**
     * Get customized
     *
     * @return customized
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getCustomized() {
        return customized;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomized(HrefObject customized) {
        this.customized = customized;
    }

    public PageRootLinks preview(HrefObject preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(HrefObject preview) {
        this.preview = preview;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PageRootLinks pageRootLinks = (PageRootLinks) o;
        return Objects.equals(this.self, pageRootLinks.self) && Objects.equals(this._default, pageRootLinks._default)
                && Objects.equals(this.customized, pageRootLinks.customized)
                && Objects.equals(this.preview, pageRootLinks.preview);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, _default, customized, preview);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PageRootLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    _default: ").append(toIndentedString(_default)).append("\n");
        sb.append("    customized: ").append(toIndentedString(customized)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
